The files in this directory contain fsnotify.

To update, erase it and run:

pip install fsnotify --target .

Note: Verify if the license brought in from the library downloaded is OK


This folder should be automatically added to the PYTHONPATH when needed.

IMPORTANT: Keep __init__.py in directory